@@ -206,6 +206,12 @@ glmc_vec2_clamp(vec2 v, float minval, float maxval) {
   glm_vec2_clamp(v, minval, maxval);
 }
 
+CGLM_EXPORT
+void
+glmc_vec2_abs(vec2 v, vec2 dest) {
+  glm_vec2_abs(v, dest);
+}
+
 CGLM_EXPORT
 void
 glmc_vec2_lerp(vec2 from, vec2 to, float t, vec2 dest) {
