@@ -379,6 +379,7 @@ TEST_DECLARE(glm_vec2_distance)
 TEST_DECLARE(glm_vec2_maxv)
 TEST_DECLARE(glm_vec2_minv)
 TEST_DECLARE(glm_vec2_clamp)
+TEST_DECLARE(glm_vec2_abs)
 TEST_DECLARE(glm_vec2_lerp)
 TEST_DECLARE(glm_vec2_complex_mul)
 TEST_DECLARE(glm_vec2_complex_div)
@@ -416,6 +417,7 @@ TEST_DECLARE(glmc_vec2_distance)
 TEST_DECLARE(glmc_vec2_maxv)
 TEST_DECLARE(glmc_vec2_minv)
 TEST_DECLARE(glmc_vec2_clamp)
+TEST_DECLARE(glmc_vec2_abs)
 TEST_DECLARE(glmc_vec2_lerp)
 TEST_DECLARE(glmc_vec2_complex_mul)
 TEST_DECLARE(glmc_vec2_complex_div)
@@ -746,6 +748,7 @@ TEST_DECLARE(glm_ivec2_distance)
 TEST_DECLARE(glm_ivec2_maxv)
 TEST_DECLARE(glm_ivec2_minv)
 TEST_DECLARE(glm_ivec2_clamp)
+TEST_DECLARE(glm_ivec2_abs)
 
 TEST_DECLARE(glmc_ivec2)
 TEST_DECLARE(glmc_ivec2_copy)
@@ -762,6 +765,7 @@ TEST_DECLARE(glmc_ivec2_distance)
 TEST_DECLARE(glmc_ivec2_maxv)
 TEST_DECLARE(glmc_ivec2_minv)
 TEST_DECLARE(glmc_ivec2_clamp)
+TEST_DECLARE(glmc_ivec2_abs)
 
 /* ivec3 */
 TEST_DECLARE(glm_ivec3)
@@ -812,6 +816,7 @@ TEST_DECLARE(glm_ivec4_distance)
 TEST_DECLARE(glm_ivec4_maxv)
 TEST_DECLARE(glm_ivec4_minv)
 TEST_DECLARE(glm_ivec4_clamp)
+TEST_DECLARE(glm_ivec4_abs)
 
 TEST_DECLARE(glmc_ivec4)
 TEST_DECLARE(glmc_ivec4_copy)
@@ -828,6 +833,7 @@ TEST_DECLARE(glmc_ivec4_distance)
 TEST_DECLARE(glmc_ivec4_maxv)
 TEST_DECLARE(glmc_ivec4_minv)
 TEST_DECLARE(glmc_ivec4_clamp)
+TEST_DECLARE(glmc_ivec4_abs)
 
 /* structs */
 TEST_DECLARE(mat3s_identity_init)
@@ -1244,6 +1250,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec2_maxv)
   TEST_ENTRY(glmc_vec2_minv)
   TEST_ENTRY(glmc_vec2_clamp)
+  TEST_ENTRY(glmc_vec2_abs)
   TEST_ENTRY(glmc_vec2_lerp)
   TEST_ENTRY(glmc_vec2_complex_mul)
   TEST_ENTRY(glmc_vec2_complex_div)
@@ -1573,6 +1580,7 @@ TEST_LIST {
   TEST_ENTRY(glm_ivec2_maxv)
   TEST_ENTRY(glm_ivec2_minv)
   TEST_ENTRY(glm_ivec2_clamp)
+  TEST_ENTRY(glm_ivec2_abs)
 
   TEST_ENTRY(glmc_ivec2)
   TEST_ENTRY(glmc_ivec2_copy)
@@ -1589,6 +1597,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_ivec2_maxv)
   TEST_ENTRY(glmc_ivec2_minv)
   TEST_ENTRY(glmc_ivec2_clamp)
+  TEST_ENTRY(glmc_ivec2_abs)
 
   /* ivec3 */
   TEST_ENTRY(glm_ivec3)
@@ -1655,6 +1664,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_ivec4_maxv)
   TEST_ENTRY(glmc_ivec4_minv)
   TEST_ENTRY(glmc_ivec4_clamp)
+  TEST_ENTRY(glmc_ivec4_abs)
 
   /* structs */
   TEST_ENTRY(mat3s_identity_init)
